/*
 # Be Name Khoda
 # Example code for the NOKIA 5110 LCD
 # Company    : AftabRayaneh
 # Website    : http://shop.aftabrayaneh.com
 # Editor     : Saleh Khademi
 # Date       : 28.08.2013
 # Version    : 1.0

 # Connect your LCD to the following Arduino pins:

 # pin 7 - Serial clock out (SCLK)
 # pin 6 - Serial data out (DIN)
 # pin 5 - Data/Command select (D/C)
 # pin 4 - LCD chip select (CS)
 # pin 3 - LCD reset (RST)
*/

#include <LCD_GFX.h>
#include <NOKIA5110.h>

NOKIA5110 display2 = NOKIA5110(7, 6, 5, 4, 3);

#define NUMFLAKES 10
#define XPOS 0
#define YPOS 1
#define DELTAY 2


#define LOGO16_GLCD_HEIGHT 16
#define LOGO16_GLCD_WIDTH  16

static unsigned char PROGMEM logo16_glcd_bmp[] =
{ B00000000, B11000000,
  B00000001, B11000000,
  B00000001, B11000000,
  B00000011, B11100000,
  B11110011, B11100000,
  B11111110, B11111000,
  B01111110, B11111111,
  B00110011, B10011111,
  B00011111, B11111100,
  B00001101, B01110000,
  B00011011, B10100000,
  B00111111, B11100000,
  B00111111, B11110000,
  B01111100, B11110000,
  B01110000, B01110000,
  B00000000, B00110000 };

void setup()   {
  Serial.begin(9600);

  display2.begin();
  // init done

  // you can change the contrast around to adapt the display
  // for the best viewing!
  display2.setContrast(45);

  display2.display(); // show splashscreen
  delay(2000);
  display2.clearDisplay();   // clears the screen and buffer
  
  display2.println("Aftab Rayaneh");   //Write a Text
  display2.setTextSize(2);
  display2.display();
  delay(2000);
  display2.clearDisplay();
  
  // draw a single pixel
  display2.drawPixel(10, 10, BLACK);
  display2.display();
  delay(2000);
  display2.clearDisplay();

   
  // draw many lines
  testdrawline();
  display2.display();
  delay(2000);
  display2.clearDisplay();

  // draw rectangles
  testdrawrect();
  display2.display();
  delay(2000);
  display2.clearDisplay();

  // draw multiple rectangles
  testfillrect();
  display2.display();
  delay(2000);
  display2.clearDisplay();

  // draw mulitple circles
  testdrawcircle();
  display2.display();
  delay(2000);
  display2.clearDisplay();

  // draw a circle, 10 pixel radius
  display2.fillCircle(display2.width()/2, display2.height()/2, 10, BLACK);
  display2.display();
  delay(2000);
  display2.clearDisplay();

  testdrawroundrect();
  delay(2000);
  display2.clearDisplay();

  testfillroundrect();
  delay(2000);
  display2.clearDisplay();

  testdrawtriangle();
  delay(2000);
  display2.clearDisplay();
   
  testfilltriangle();
  delay(2000);
  display2.clearDisplay();

  // draw the first ~12 characters in the font
  testdrawchar();
  display2.display();
  delay(2000);
  display2.clearDisplay();

  // text display tests
  display2.setTextSize(1);
  display2.setTextColor(BLACK);
  display2.setCursor(0,0);
  display2.println("Hello, world!");
  display2.setTextColor(WHITE, BLACK); // 'inverted' text
  display2.println(3.141592);
  display2.setTextSize(2);
  display2.setTextColor(BLACK);
  display2.print("0x"); display2.println(0xDEADBEEF, HEX);
  display2.display();
  delay(2000);

  // miniature bitmap display
  display2.clearDisplay();
  display2.drawBitmap(30, 16,  logo16_glcd_bmp, 16, 16, 1);
  display2.display();

  // invert the display
  display2.invertDisplay(true);
  delay(1000); 
  display2.invertDisplay(false);
  delay(1000); 

  // draw a bitmap icon and 'animate' movement
  testdrawbitmap(logo16_glcd_bmp, LOGO16_GLCD_HEIGHT, LOGO16_GLCD_WIDTH);
}


void loop() {
  
}


void testdrawbitmap(const uint8_t *bitmap, uint8_t w, uint8_t h) {
  uint8_t icons[NUMFLAKES][3];
  srandom(666);     // whatever seed
 
  // initialize
  for (uint8_t f=0; f< NUMFLAKES; f++) {
    icons[f][XPOS] = random() % display2.width();
    icons[f][YPOS] = 0;
    icons[f][DELTAY] = random() % 5 + 1;
    
    Serial.print("x: ");
    Serial.print(icons[f][XPOS], DEC);
    Serial.print(" y: ");
    Serial.print(icons[f][YPOS], DEC);
    Serial.print(" dy: ");
    Serial.println(icons[f][DELTAY], DEC);
  }

  while (1) {
    // draw each icon
    for (uint8_t f=0; f< NUMFLAKES; f++) {
      display2.drawBitmap(icons[f][XPOS], icons[f][YPOS], logo16_glcd_bmp, w, h, BLACK);
    }
    display2.display();
    delay(200);
    
    // then erase it + move it
    for (uint8_t f=0; f< NUMFLAKES; f++) {
      display2.drawBitmap(icons[f][XPOS], icons[f][YPOS],  logo16_glcd_bmp, w, h, WHITE);
      // move it
      icons[f][YPOS] += icons[f][DELTAY];
      // if its gone, reinit
      if (icons[f][YPOS] > display2.height()) {
	icons[f][XPOS] = random() % display2.width();
	icons[f][YPOS] = 0;
	icons[f][DELTAY] = random() % 5 + 1;
      }
    }
   }
}


void testdrawchar(void) {
  display2.setTextSize(1);
  display2.setTextColor(BLACK);
  display2.setCursor(0,0);

  for (uint8_t i=0; i < 168; i++) {
    if (i == '\n') continue;
    display2.write(i);
    //if ((i > 0) && (i % 14 == 0))
      //display2.println();
  }    
  display2.display();
}

void testdrawcircle(void) {
  for (int16_t i=0; i<display2.height(); i+=2) {
    display2.drawCircle(display2.width()/2, display2.height()/2, i, BLACK);
    display2.display();
  }
}

void testfillrect(void) {
  uint8_t color = 1;
  for (int16_t i=0; i<display2.height()/2; i+=3) {
    // alternate colors
    display2.fillRect(i, i, display2.width()-i*2, display2.height()-i*2, color%2);
    display2.display();
    color++;
  }
}

void testdrawtriangle(void) {
  for (int16_t i=0; i<min(display2.width(),display2.height())/2; i+=5) {
    display2.drawTriangle(display2.width()/2, display2.height()/2-i,
                     display2.width()/2-i, display2.height()/2+i,
                     display2.width()/2+i, display2.height()/2+i, BLACK);
    display2.display();
  }
}

void testfilltriangle(void) {
  uint8_t color = BLACK;
  for (int16_t i=min(display2.width(),display2.height())/2; i>0; i-=5) {
    display2.fillTriangle(display2.width()/2, display2.height()/2-i,
                     display2.width()/2-i, display2.height()/2+i,
                     display2.width()/2+i, display2.height()/2+i, color);
    if (color == WHITE) color = BLACK;
    else color = WHITE;
    display2.display();
  }
}

void testdrawroundrect(void) {
  for (int16_t i=0; i<display2.height()/2-2; i+=2) {
    display2.drawRoundRect(i, i, display2.width()-2*i, display2.height()-2*i, display2.height()/4, BLACK);
    display2.display();
  }
}

void testfillroundrect(void) {
  uint8_t color = BLACK;
  for (int16_t i=0; i<display2.height()/2-2; i+=2) {
    display2.fillRoundRect(i, i, display2.width()-2*i, display2.height()-2*i, display2.height()/4, color);
    if (color == WHITE) color = BLACK;
    else color = WHITE;
    display2.display();
  }
}
   
void testdrawrect(void) {
  for (int16_t i=0; i<display2.height()/2; i+=2) {
    display2.drawRect(i, i, display2.width()-2*i, display2.height()-2*i, BLACK);
    display2.display();
  }
}

void testdrawline() {  
  for (int16_t i=0; i<display2.width(); i+=4) {
    display2.drawLine(0, 0, i, display2.height()-1, BLACK);
    display2.display();
  }
  for (int16_t i=0; i<display2.height(); i+=4) {
    display2.drawLine(0, 0, display2.width()-1, i, BLACK);
    display2.display();
  }
  delay(250);
  
  display2.clearDisplay();
  for (int16_t i=0; i<display2.width(); i+=4) {
    display2.drawLine(0, display2.height()-1, i, 0, BLACK);
    display2.display();
  }
  for (int8_t i=display2.height()-1; i>=0; i-=4) {
    display2.drawLine(0, display2.height()-1, display2.width()-1, i, BLACK);
    display2.display();
  }
  delay(250);
  
  display2.clearDisplay();
  for (int16_t i=display2.width()-1; i>=0; i-=4) {
    display2.drawLine(display2.width()-1, display2.height()-1, i, 0, BLACK);
    display2.display();
  }
  for (int16_t i=display2.height()-1; i>=0; i-=4) {
    display2.drawLine(display2.width()-1, display2.height()-1, 0, i, BLACK);
    display2.display();
  }
  delay(250);

  display2.clearDisplay();
  for (int16_t i=0; i<display2.height(); i+=4) {
    display2.drawLine(display2.width()-1, 0, 0, i, BLACK);
    display2.display();
  }
  for (int16_t i=0; i<display2.width(); i+=4) {
    display2.drawLine(display2.width()-1, 0, i, display2.height()-1, BLACK); 
    display2.display();
  }
  delay(250);
}